DistMult
========

.. currentmodule:: pykeen.models

.. autoclass:: DistMult
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DistMult.hpo_default
      ~DistMult.regularizer_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~DistMult.interaction_function
      ~DistMult.score_h
      ~DistMult.score_hrt
      ~DistMult.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: regularizer_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: interaction_function
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_t
